@@ -1,6 +1,6 @@
 # -*-mode: python; fill-column: 75; tab-width: 8; coding: iso-latin-1-unix -*-
 #
-# $Id: Tix.py 46691 2006-06-06 12:46:55Z martin.blais $
+# $Id: Tix.py 52785 2006-11-18 18:42:22Z martin.v.loewis $
 #
 # Tix.py -- Tix widget wrappers.
 #
@@ -421,7 +421,7 @@ class TixSubWidget(TixWidget):
             except:
                 plist = []
 
-        if (not check_intermediate) or len(plist) < 2:
+        if not check_intermediate:
             # immediate descendant
             TixWidget.__init__(self, master, None, None, {'name' : name})
         else:
@@ -437,6 +437,9 @@ class TixSubWidget(TixWidget):
                     parent = TixSubWidget(parent, plist[i],
                                           destroy_physically=0,
                                           check_intermediate=0)
+            # The Tk widget name is in plist, not in name
+            if plist:
+                name = plist[-1]
             TixWidget.__init__(self, parent, None, None, {'name' : name})
         self.destroy_physically = destroy_physically
 
