@@ -15,6 +15,7 @@ pictures can easily be drawn.
 """
 
 from math import * # Also for export
+from time import sleep
 import Tkinter
 
 speeds = ['fastest', 'fast', 'normal', 'slow', 'slowest']
@@ -305,6 +306,7 @@ class RawPen:
                                             {'fill': self._color,
                                              'smooth': smooth})
                 self._items.append(item)
+                self._canvas.update()
         self._path = []
         self._filling = flag
         if flag:
@@ -761,7 +763,7 @@ def setup(**geometry):
 
     startx = geometry.get('startx', _startx)
     if startx >= 0 or startx == None:
-        _startx = _startx
+        _startx = startx
     else:
         raise ValueError, "startx can not be less than 0"
 
@@ -949,7 +951,6 @@ def demo2():
 
 
 if __name__ == '__main__':
-    from time import sleep
     demo()
     sleep(3)
     demo2()
